pub enum DistributionType {
LinearVesting {
percentage: Decimal,
start_time: u64,
end_time: u64,
cliff_duration: Option<u64>,
},
LumpSum {
percentage: Decimal,
start_time: u64,
},
}Variants
LinearVesting
The distribution is done in a linear vesting schedule
Fields
LumpSum
The distribution is done in a single lump sum, i.e. no vesting period
Implementations
Sourceimpl DistributionType
impl DistributionType
pub fn has_started(&self, current_time: &Timestamp) -> bool