pub enum ExecuteMsg {
ManageCampaign {
action: CampaignAction,
},
Claim {
receiver: Option<String>,
amount: Option<Uint128>,
},
AddAllocations {
allocations: Vec<(String, Uint128)>,
},
ReplaceAddress {
old_address: String,
new_address: String,
},
RemoveAddress {
address: String,
},
BlacklistAddress {
address: String,
blacklist: bool,
},
ManageAuthorizedWallets {
addresses: Vec<String>,
authorized: bool,
},
Sweep {
denom: String,
amount: Option<Uint128>,
},
UpdateOwnership(Action),
}Variants
ManageCampaign
Manages campaigns based on the action, defined by CampaignAction.
Fields
action: CampaignActionClaim
Claims rewards from a campaign
Fields
AddAllocations
Adds a batch of addresses and their allocations. This can only be done before the campaign has started.
ReplaceAddress
Replaces an address in the allocation list. This can only be done before the campaign has started.
RemoveAddress
Removes an address in the allocation list. This can only be done before the campaign has started.
BlacklistAddress
Blacklists or unblacklists an address. This can be done at any time.
Fields
ManageAuthorizedWallets
Manages authorized wallets that can perform admin actions. Only the owner can manage authorized wallets.
Fields
Whether to authorize or unauthorize the addresses
Sweep
Sweep non-reward tokens from the contract (owner only) This allows retrieving any tokens accidentally sent to the contract that are not the campaign’s reward denom
Fields
UpdateOwnership(Action)
Update the contract’s ownership. The action to be provided
can be either to propose transferring ownership to an account,
accept a pending ownership transfer, or renounce the ownership
permanently.