pub struct Campaign {
pub name: String,
pub description: String,
pub ty: String,
pub total_reward: Coin,
pub claimed: Coin,
pub distribution_type: Vec<DistributionType>,
pub start_time: u64,
pub end_time: u64,
pub closed: Option<u64>,
}Expand description
Represents a campaign.
Fields
name: StringThe campaign name
description: StringThe campaign description
ty: StringCampaign type. Value used by front ends.
total_reward: CoinThe total amount of the reward asset that is intended to be allocated to the campaign
claimed: CoinThe amount of the reward asset that has been claimed
distribution_type: Vec<DistributionType>The ways the reward is distributed, which are defined by the DistributionType. The sum of the percentages must be 100.
start_time: u64The campaign start time (unix timestamp), in seconds
end_time: u64The campaign end time (unix timestamp), in seconds
closed: Option<u64>The timestamp at which the campaign was closed, in seconds
Implementations
Sourceimpl Campaign
impl Campaign
Sourcepub fn from_params(params: CampaignParams) -> Self
pub fn from_params(params: CampaignParams) -> Self
Creates a new campaign from the given parameters
Sourcepub fn has_started(&self, current_time: &Timestamp) -> bool
pub fn has_started(&self, current_time: &Timestamp) -> bool
Checks if the campaign has started