pub struct RewardsResponse {
pub claimed: Vec<Coin>,
pub pending: Vec<Coin>,
pub available_to_claim: Vec<Coin>,
}Expand description
Response to the Rewards query.
Fields
claimed: Vec<Coin>The tokens that have been claimed by the address.
pending: Vec<Coin>The total amount of tokens that is pending to be claimed by the address.
available_to_claim: Vec<Coin>The tokens that are available to be claimed by the address.