ExecuteMsg

Enum ExecuteMsg 

pub enum ExecuteMsg {
    ManageCampaign {
        action: CampaignAction,
    },
    Claim {
        receiver: Option<String>,
        amount: Option<Uint128>,
    },
    AddAllocations {
        allocations: Vec<(String, Uint128)>,
    },
    ReplaceAddress {
        old_address: String,
        new_address: String,
    },
    RemoveAddress {
        address: String,
    },
    BlacklistAddress {
        address: String,
        blacklist: bool,
    },
    ManageAuthorizedWallets {
        addresses: Vec<String>,
        authorized: bool,
    },
    Sweep {
        denom: String,
        amount: Option<Uint128>,
    },
    UpdateOwnership(Action),
}

Variants



ManageCampaign

Manages campaigns based on the action, defined by CampaignAction.

Fields



Claim

Claims rewards from a campaign

Fields

receiver: Option<String>

The receiver address of the claimed rewards. If not set, the sender of the message will be the receiver. This is useful for allowing a contract to do the claim operation on behalf of a user.

amount: Option<Uint128>

The amount to claim. If not set, all available tokens will be claimed.



AddAllocations

Adds a batch of addresses and their allocations. This can only be done before the campaign has started.

Fields

allocations: Vec<(String, Uint128)>

Vector of (address, amount) pairs



ReplaceAddress

Replaces an address in the allocation list. This can only be done before the campaign has started.

Fields

old_address: String

The old address to replace

new_address: String

The new address to use



RemoveAddress

Removes an address in the allocation list. This can only be done before the campaign has started.

Fields

address: String

The address to remove



BlacklistAddress

Blacklists or unblacklists an address. This can be done at any time.

Fields

address: String

The address to blacklist/unblacklist

blacklist: bool

Whether to blacklist or unblacklist



ManageAuthorizedWallets

Manages authorized wallets that can perform admin actions. Only the owner can manage authorized wallets.

Fields

addresses: Vec<String>

Vector of addresses to authorize/unauthorize

authorized: bool

Whether to authorize or unauthorize the addresses



Sweep

Sweep non-reward tokens from the contract (owner only) This allows retrieving any tokens accidentally sent to the contract that are not the campaign’s reward denom

Fields

denom: String

The denomination of the token to sweep

amount: Option<Uint128>

Optional amount to sweep. If not provided, sweeps entire balance



UpdateOwnership(Action)

Update the contract’s ownership. The action to be provided can be either to propose transferring ownership to an account, accept a pending ownership transfer, or renounce the ownership permanently.